introspectiontools.get_current_function_name
============================================

.. autofunction:: abjad.tools.introspectiontools.get_current_function_name.get_current_function_name
   :noindex:
